﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Microsoft.Phone.Shell;

using Xamarin.Geolocation;

using Support;

namespace LongDriveWP8
{
    public partial class PivotBetweenDriveAndScores : PhoneApplicationPage
    {
        Xamarin.Geolocation.Position first, second;
        Xamarin.Geolocation.Geolocator geo;
        DateTime startingTime, endingTime;
        App _app;
        int startingPoint = 0, PageSize = 20;
                
        public PivotBetweenDriveAndScores()
        {
            InitializeComponent();
            geo = new Geolocator();
            _app = (App)Application.Current;
        }

        async private void LandingSpot_Tap(object sender, System.Windows.Input.GestureEventArgs e)
        {
            LandingSpot.IsEnabled = false;
            endingTime = DateTime.UtcNow;
            second = await geo.GetPositionAsync(30000);
            await geo.GetPositionAsync(timeout: 30000).ContinueWith(t =>
            {
                second = t.Result;
                LandingSpot.IsEnabled = false;
                DriveSpot.IsEnabled = true;
                PostDrive();
            }, TaskScheduler.FromCurrentSynchronizationContext());
            MessageBox.Show("Your Drive has been recorded.");
        }

        async private void DriveSpot_Tap(object sender, System.Windows.Input.GestureEventArgs e)
        {
            DriveSpot.IsEnabled = false;
            startingTime = DateTime.UtcNow;
            await geo.GetPositionAsync(timeout: 30000).ContinueWith(t =>
                {
                    first = t.Result;
                    LandingSpot.IsEnabled = true;
                }, TaskScheduler.FromCurrentSynchronizationContext());
        }

        private void PivotItem_GotFocus(object sender, RoutedEventArgs e)
        {

        }

        async void PostDrive()
        {
            Drive d = new Drive();
            d.StartingLat = first.Latitude;
            d.StartingLon = first.Longitude;
            d.EndingLat = second.Latitude;
            d.EndingLon = second.Longitude;
            d.StartingTime = startingTime;
            d.EndingTime = endingTime;
            d.deviceType = (int)Support.AppConstants.DeviceType.WindowsPhone8;
            d.ChannelUri = _app.CurrentChannel.ChannelUri.ToString();
            d.DeviceToken = String.Empty;

            try
            {
                await _app.client.GetTable<Support.Drive>().InsertAsync(d);
            }
            catch (System.Exception exc)
            {
                Console.WriteLine(exc.Message);
            }
        }

        private void LongDriveOptions_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (2 == LongDriveOptions.SelectedIndex)
            {
                DisplayDriveInfo();
            }
        }

        private async System.Threading.Tasks.Task DisplayDriveInfo()
        {
            try
            {
                var drives = _app.client.GetTable<Support.Drive>();
                var query = drives.OrderByDescending(drive => drive.Distance).Skip(startingPoint).Take(PageSize);
                var listedDrives = await query.ToListAsync();
                foreach (var item in listedDrives)
                {
                    item.Distance = 1.09 * item.Distance;
                }
                lbScores.DataContext = listedDrives;
            }
            catch(System.Exception sysExc)
            {
                Console.WriteLine(sysExc.Message);
            }
        }
    }
}