using System;
using System.Collections.Generic;
using System.Drawing;

using MonoTouch.CoreFoundation;
using MonoTouch.UIKit;
using MonoTouch.Foundation;

using Microsoft.WindowsAzure.MobileServices;

namespace LongDriveiOS
{
    public class CurrentStandingsController : UITableViewController
    {
        int startingPoint = 0, PageSize = 20;
        string cellIdentifier = "DriveCell";
        List<Support.Drive> listedDrives;
        AppDelegate app;
        UIBarButtonItem previous, next;
        public CurrentStandingsController()
        {
            app = (AppDelegate)UIApplication.SharedApplication.Delegate;
            listedDrives = new List<Support.Drive>();
        }

        public override void DidReceiveMemoryWarning()
        {
            // Releases the view if it doesn't have a superview.
            base.DidReceiveMemoryWarning();

            // Release any cached data, images, etc that aren't in use.
        }

        public override void ViewDidLoad()
        {
            base.ViewDidLoad();
            this.Title = "Scoreboard";
            previous = new UIBarButtonItem();
            previous.Title = "< Previous";
            previous.Style = UIBarButtonItemStyle.Plain;
            previous.Clicked += previous_Clicked;
            this.NavigationItem.LeftBarButtonItem = previous;
            next = new UIBarButtonItem();
            next.Title = "Next >";
            next.Style = UIBarButtonItemStyle.Plain;
            next.Clicked += next_Clicked;
            this.NavigationItem.RightBarButtonItem = next;
        }

        async public override void ViewWillAppear(bool animated)
        {
            base.ViewWillAppear(animated);
            await DisplayDriveInfo();
        }

        private async System.Threading.Tasks.Task DisplayDriveInfo()
        {
            try
            {
                var drives = app.client.GetTable<Support.Drive>();
                
                var query = drives.OrderByDescending(drive => drive.Distance).Skip(startingPoint).Take(PageSize);
                listedDrives = await query.ToListAsync();
                //listedDrives = await query.ToListAsync();
                this.TableView.ReloadData();
            }
            catch(System.Exception sysExc)
            {
                Console.WriteLine(sysExc.Message);
            }
        }

        async void next_Clicked(object sender, EventArgs e)
        {
            startingPoint += PageSize;
            await DisplayDriveInfo();
        }

        async void previous_Clicked(object sender, EventArgs e)
        {
            startingPoint -= PageSize;
            if (startingPoint < 0)
            {
                startingPoint = 0;
            }
            await DisplayDriveInfo();
        }

        public override void ViewDidAppear(bool animated)
        {
            base.ViewDidAppear(animated);
        }

        public override UITableViewCell GetCell(UITableView tableView, NSIndexPath indexPath)
        {
            UITableViewCell cell = TableView.DequeueReusableCell(cellIdentifier);
            if (cell == null)
            {
                cell = new UITableViewCell(UITableViewCellStyle.Subtitle, cellIdentifier);
            }
            var yrds = Convert.ToInt32((listedDrives[indexPath.Row].Distance * 1.09));
            cell.TextLabel.Text = String.Format("{0:D} yards", yrds);
            var date = listedDrives[indexPath.Row].StartingTime.ToShortDateString();
            var time = listedDrives[indexPath.Row].StartingTime.ToShortTimeString();
            cell.DetailTextLabel.Text = String.Format("{0} {1}", date, time);
            return cell;
        }

        public override int RowsInSection(UITableView tableview, int section)
        {
            return listedDrives.Count;
        }
    }
}